/*
 *    _           _             _   _
 *   (_) __ _  __| | __ _ _ __ | |_(_)_   _____
 *   | |/ _` |/ _` |/ _` | '_ \| __| \ \ / / _ \
 *   | | (_| | (_| | (_| | |_) | |_| |\ V /  __/
 *  _/ |\__,_|\__,_|\__,_| .__/ \__|_| \_/ \___|
 * |__/                  |_|
 *
 * This file is part of the Maverick Synergy Hotfixes Java SSH API
 *
 * Unauthorized copying of this file, via any medium is strictly prohibited.
 *
 * Copyright (C) 2002-2021 JADAPTIVE Limited - All Rights Reserved
 *
 * Use of this software may also be covered by third-party licenses depending on the choices you make about what features to use.
 *
 * Please visit the link below to see additional third-party licenses and copyrights
 *
 * https://www.jadaptive.com/app/manpage/en/article/1565029/What-third-party-dependencies-does-the-Maverick-Synergy-API-have
 */
package com.sshtools.common.policy;

import java.util.Collection;
import java.util.Collections;
import java.util.Set;
import java.util.TreeSet;

public class SignaturePolicy {

	Set<String> supportedSignatures = new TreeSet<>();
	boolean strictMode;
	
	public SignaturePolicy() {	
	}
		
	public SignaturePolicy(Collection<String> supportedSignatures) {
		this.supportedSignatures.addAll(supportedSignatures);
		this.strictMode = false;
	}
	
	public SignaturePolicy(Collection<String> supportedSignatures, boolean strictMode) {
		this.supportedSignatures.addAll(supportedSignatures);
		this.strictMode = strictMode;
	}
	
	public Set<String> getSupportedSignatures() {
		return Collections.unmodifiableSet(supportedSignatures);
	}
	
	public void setSupportedSignatures(Collection<String> supportedSignatures) {
		this.supportedSignatures = new TreeSet<>(supportedSignatures);
	}
	
	public boolean isStrictMode() {
		return strictMode;
	}
	
	public void setStrictMode(boolean strictMode) {
		this.strictMode = strictMode;
	}
}
